@@ -486,6 +486,7 @@ class ParametersLEDET:
         if(type(variableGroup) != dict):
             for k in variableGroup.__annotations__:
                 if (k == "BlankRows"): continue
+                print(variableLabels[k])
                 print(k, self.getAttribute(variableGroup, k))
         else:
             self.variableGroupInputs = asdict(self.Inputs)
@@ -494,9 +495,8 @@ class ParametersLEDET:
             self.variableGroupVariables = asdict(self.Variables)
             for k in variableGroup:
                 if (k == "BlankRows"): continue
-                print(variableGroup[k])
-                print(k)
-               # print(k, variableGroup[k])
+                print(variableLabels[k])
+                print(k, variableGroup[k])
 
     def getNumberOfCoilSections(self):
         k = self.Inputs.M_m
