@@ -6,6 +6,7 @@ import shutil
 
 from steam_nb_api.resources.ResourceReader import ResourceReader
 from steam_nb_api.utils.misc import makeCopyFile
+from steam_nb_api.ledet.ParametersLEDET import ParametersLEDET
 
 class ParametersCOSIM:
     '''
@@ -497,31 +498,18 @@ class ParametersCOSIM:
         ## Do some kind of check
         TurnNumber_All = TurnNumber*N_PAR
 
+        print(TurnNumber_All,'will be simulated in parallel.')
         if TurnNumber_All >= 10000:
             print("You are trying to simulate ",str(TurnNumber_All),"in parallel mode. \n")
             maxN_PAR = np.floor(10000/TurnNumber)
             print("Consider not to user more than ", str(maxN_PAR)," parallel Simulations.")
 
     def prepareSingleLEDETFile(self, file):
-        df_full = pd.read_excel(file, sheet_name=None, header=None)
-        df = df_full["Options"]
-        df.rename(columns={0: 'a', 1: 'b', 2: 'c'}, inplace=True)
-        df.loc[df['b'] == 'flag_generateReport', 'c'] = 0
-        df.loc[df['b'] == 'flag_saveMatFile', 'c'] = 0
-        df_full["Options"] = df
-
-        df = df_full['Inputs']
-        df.rename(columns={0: 'a', 1: 'b', 2: 'c'}, inplace=True)
-        x = df.loc[df['b'] == 'HalfTurnToInductanceBlock']
-        x = x.iloc[0]
-        TurnNumber = max(x[2:-1])
-
-        writer = pd.ExcelWriter(file)
-        df_full['Inputs'].to_excel(writer, index=False, index_label=False, header=False, sheet_name='Inputs')
-        df_full['Options'].to_excel(writer, index=False, index_label=False, header=False, sheet_name='Options')
-        df_full['Plots'].to_excel(writer, index=False, index_label=False, header=False, sheet_name='Plots')
-        df_full['Variables'].to_excel(writer, index=False, index_label=False, header=False,
-                                      sheet_name='Variables')
-        writer.save()
-
+        a = ParametersLEDET()
+        a.readLEDETExcel(file)
+        a.Options.flag_useExternalInitialization = 0
+        a.Options.flag_generateReport = 0
+        a.Options.flag_saveMatFile = 0
+        a.writeFileLEDET(file)
+        TurnNumber = max(a.Inputs.HalfTurnToInductanceBlock)
         return TurnNumber
